summaryrefslogtreecommitdiffstats
path: root/kdecore/kcompletion.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdecore/kcompletion.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/kcompletion.h')
-rw-r--r--kdecore/kcompletion.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kdecore/kcompletion.h b/kdecore/kcompletion.h
index 95198cdb0..15c6ca288 100644
--- a/kdecore/kcompletion.h
+++ b/kdecore/kcompletion.h
@@ -119,7 +119,7 @@ class TQPopupMenu;
* tell the user) where a completion comes from.
*
* Note: KCompletion does not work with strings that contain 0x0 characters
- * (unicode nul), as this is used internally as a delimiter.
+ * (tqunicode nul), as this is used internally as a delimiter.
*
* You may inherit from KCompletion and override makeCompletion() in
* special cases (like reading directories/urls and then supplying the
@@ -129,7 +129,7 @@ class TQPopupMenu;
*
* @author Carsten Pfeiffer <pfeiffer@kde.org>
*/
-class KDECORE_EXPORT KCompletion : public QObject
+class KDECORE_EXPORT KCompletion : public TQObject
{
Q_ENUMS( CompOrder )
Q_PROPERTY( CompOrder order READ order WRITE setOrder )
@@ -160,7 +160,7 @@ public:
virtual ~KCompletion();
/**
* Attempts to find an item in the list of available completions,
* that begins with @p string. Will either return the first matching item
* (if there is more than one match) or TQString::null, if no match was
* found.
@@ -244,7 +244,7 @@ public:
TQStringList items() const;
/**
- * Returns true when the completion object contains no entries.
+ * Returns true when the completion object tqcontains no entries.
*/
bool isEmpty() const;
@@ -354,7 +354,7 @@ public:
/**
* Enables/disables playing a sound when
- * @li makeCompletion() can't find a match
+ * @li makeCompletion() can't tqfind a match
* @li there is a partial completion (= multiple matches in
* Shell-completion mode)
* @li nextMatch() or previousMatch() hit the last possible
@@ -553,8 +553,8 @@ protected:
private:
void addWeightedItem( const TQString& );
- TQString findCompletion( const TQString& string );
- void findAllCompletions( const TQString&,
+ TQString tqfindCompletion( const TQString& string );
+ void tqfindAllCompletions( const TQString&,
KCompletionMatchesWrapper *matches,
bool& hasMultipleMatches ) const;
@@ -829,7 +829,7 @@ public:
*
* @param mode Completion type:
* @li CompletionNone: Disables completion feature.
* @li CompletionAuto: Attempts to find a match &
* fills-in the remaining text.
* @li CompletionMan: Acts the same as the above
* except the action has to be
@@ -892,7 +892,7 @@ public:
*
* This methods returns the key-binding used to activate
* the feature feature given by @p item. If the binding
- * contains modifier key(s), the SUM of the modifier key
+ * tqcontains modifier key(s), the SUM of the modifier key
* and the actual key code are returned.
*
* @param item the item to check
@@ -160,7 +160,7 @@ public:
virtual ~KCompletion();
/**
- * Attempts to find an item in the list of available completions,
+ * Attempts to tqfind an item in the list of available completions,
* that begins with @p string. Will either return the first matching item
* (if there is more than one match) or TQString::null, if no match was
@@ -829,7 +829,7 @@ public:
* @param mode Completion type:
* @li CompletionNone: Disables completion feature.
- * @li CompletionAuto: Attempts to find a match &
+ * @li CompletionAuto: Attempts to tqfind a match &
* fills-in the remaining text.
* @li CompletionMan: Acts the same as the above